@@ -20,9 +20,6 @@ class SocketManager:
     server = None
     client = None
 
-    level = INFO  # global attr
-    stdMode = "text/json"  # global attr
-
     lock = threading.Lock()
 
     @classmethod
