@@ -4,7 +4,7 @@ import multiprocessing
 
 from typing import List
 
-__all__ = ("DEBUG", "INFO", "WARNING", "ERROR", "level_map", "thread_or_process")
+__all__ = ("DEBUG", "INFO", "WARNING", "ERROR", "level_map", "thread_or_process", "FORMAT")
 
 DEBUG: int = 10
 INFO: int = 20
@@ -17,3 +17,8 @@ level_map: dict = {
     ERROR: "error",
 }
 thread_or_process = []  # type: List[multiprocessing.Process, threading.Thread]
+
+
+class FORMAT:
+    TEXT = "text"
+    JSON = "json"
